@@ -67,33 +67,21 @@ class ComputeEngineSSHHook(SSHHook):
     Hook to connect to a remote instance in compute engine
 
     :param instance_name: The name of the Compute Engine instance
-    :type instance_name: str
     :param zone: The zone of the Compute Engine instance
-    :type zone: str
     :param user: The name of the user on which the login attempt will be made
-    :type user: str
     :param project_id: The project ID of the remote instance
-    :type project_id: str
     :param gcp_conn_id: The connection id to use when fetching connection info
-    :type gcp_conn_id: str
     :param hostname: The hostname of the target instance. If it is not passed, it will be detected
         automatically.
-    :type hostname: str
     :param use_iap_tunnel: Whether to connect through IAP tunnel
-    :type use_iap_tunnel: bool
     :param use_internal_ip: Whether to connect using internal IP
-    :type use_internal_ip: bool
     :param use_oslogin: Whether to manage keys using OsLogin API. If false,
         keys are managed using instance metadata
-    :type use_oslogin: bool
     :param expire_time: The maximum amount of time in seconds before the private key expires
-    :type expire_time: int
     :param gcp_conn_id: The connection id to use when fetching connection information
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate, if any.
         For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     """
 
     conn_name_attr = 'gcp_conn_id'
@@ -102,7 +90,7 @@ class ComputeEngineSSHHook(SSHHook):
     hook_name = 'Google Cloud SSH'
 
     @staticmethod
-    def get_ui_field_behaviour() -> Dict:
+    def get_ui_field_behaviour() -> Dict[str, Any]:
         return {
             "hidden_fields": ['host', 'schema', 'login', 'password', 'port', 'extra'],
             "relabeling": {},
