@@ -20,6 +20,8 @@ import sys
 from copy import deepcopy
 from typing import Any, Callable, Dict, List, Optional, Sequence, Tuple, Union
 
+from airflow.providers.google.common.consts import CLIENT_INFO
+
 if sys.version_info >= (3, 8):
     from functools import cached_property
 else:
@@ -79,13 +81,9 @@ class NameDeterminer:
 
 
         :param entity: Entity
-        :type entity: any
         :param entity_id: Entity id
-        :type entity_id: str
         :param location: Location
-        :type location: str
         :param project_id: The id of Google Cloud Vision project.
-        :type project_id: str
         :return: The same entity or entity with new name
         :rtype: str
         :raises: AirflowException
@@ -150,9 +148,7 @@ class CloudVisionHook(GoogleBaseHook):
         :rtype: google.cloud.vision_v1.ProductSearchClient
         """
         if not self._client:
-            self._client = ProductSearchClient(
-                credentials=self._get_credentials(), client_info=self.client_info
-            )
+            self._client = ProductSearchClient(credentials=self._get_credentials(), client_info=CLIENT_INFO)
         return self._client
 
     @cached_property
