@@ -31,6 +31,7 @@ from airflow.providers.google.cloud.hooks.dataflow import (
     process_line_and_extract_dataflow_job_id_callback,
 )
 from airflow.providers.google.cloud.hooks.gcs import GCSHook
+from airflow.providers.google.cloud.links.dataflow import DataflowJobLink
 from airflow.version import version
 
 if TYPE_CHECKING:
@@ -58,24 +59,17 @@ class DataflowConfiguration:
     :param job_name: The 'jobName' to use when executing the Dataflow job
         (templated). This ends up being set in the pipeline options, so any entry
         with key ``'jobName'`` or  ``'job_name'``in ``options`` will be overwritten.
-    :type job_name: str
     :param append_job_name: True if unique suffix has to be appended to job name.
-    :type append_job_name: bool
     :param project_id: Optional, the Google Cloud project ID in which to start a job.
         If set to None or missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param location: Job location.
-    :type location: str
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param poll_sleep: The time in seconds to sleep between polling Google
         Cloud Platform for the dataflow job status while the job is in the
         JOB_STATE_RUNNING state.
-    :type poll_sleep: int
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -84,14 +78,11 @@ class DataflowConfiguration:
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     :param drain_pipeline: Optional, set to True if want to stop streaming job by draining it
         instead of canceling during killing task instance. See:
         https://cloud.google.com/dataflow/docs/guides/stopping-a-pipeline
-    :type drain_pipeline: bool
     :param cancel_timeout: How long (in seconds) operator should wait for the pipeline to be
-        successfully cancelled when task is being killed.
-    :type cancel_timeout: Optional[int]
+        successfully cancelled when task is being killed. (optional) default to 300s
     :param wait_until_finished: (Optional)
         If True, wait for the end of pipeline execution before exiting.
         If False, only submits job.
@@ -125,17 +116,14 @@ class DataflowConfiguration:
 
         If you in your pipeline do not call the wait_for_pipeline method, and pass wait_until_finish=False
         to the operator, the second loop will check once is job not in terminal state and exit the loop.
-    :type wait_until_finished: Optional[bool]
     :param multiple_jobs: If pipeline creates multiple jobs then monitor all jobs. Supported only by
         :py:class:`~airflow.providers.apache.beam.operators.beam.BeamRunJavaPipelineOperator`
-    :type multiple_jobs: boolean
     :param check_if_running: Before running job, validate that a previous run is not in process.
         IgnoreJob = do not check if running.
         FinishIfRunning = if job is running finish with nothing.
         WaitForRun = wait until job finished and the run job.
         Supported only by:
         :py:class:`~airflow.providers.apache.beam.operators.beam.BeamRunJavaPipelineOperator`
-    :type check_if_running: CheckJobRunning
     """
 
     template_fields: Sequence[str] = ("job_name", "location")
@@ -223,13 +211,10 @@ class DataflowCreateJavaJobOperator(BaseOperator):
         :ref:`howto/operator:DataflowCreateJavaJobOperator`
 
     :param jar: The reference to a self executing Dataflow jar (templated).
-    :type jar: str
     :param job_name: The 'jobName' to use when executing the Dataflow job
         (templated). This ends up being set in the pipeline options, so any entry
         with key ``'jobName'`` in ``options`` will be overwritten.
-    :type job_name: str
     :param dataflow_default_options: Map of default job options.
-    :type dataflow_default_options: dict
     :param options: Map of job specific options.The key must be a dictionary.
         The value can contain different types:
 
@@ -237,40 +222,30 @@ class DataflowCreateJavaJobOperator(BaseOperator):
         * If the value is False, this option will be skipped
         * If the value is True, the single option - ``--key`` (without value) will be added.
         * If the value is list, the many options will be added for each key.
-          If the value is ``['A', 'B']`` and the key is ``key`` then the ``--key=A --key-B`` options
+          If the value is ``['A', 'B']`` and the key is ``key`` then the ``--key=A --key=B`` options
           will be left
         * Other value types will be replaced with the Python textual representation.
 
         When defining labels (``labels`` option), you can also provide a dictionary.
-    :type options: dict
     :param project_id: Optional, the Google Cloud project ID in which to start a job.
         If set to None or missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param location: Job location.
-    :type location: str
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param poll_sleep: The time in seconds to sleep between polling Google
         Cloud Platform for the dataflow job status while the job is in the
         JOB_STATE_RUNNING state.
-    :type poll_sleep: int
     :param job_class: The name of the dataflow job class to be executed, it
         is often not the main class configured in the dataflow jar file.
-    :type job_class: str
 
     :param multiple_jobs: If pipeline creates multiple jobs then monitor all jobs
-    :type multiple_jobs: boolean
     :param check_if_running: before running job, validate that a previous run is not in process
-    :type check_if_running: CheckJobRunning(IgnoreJob = do not check if running, FinishIfRunning=
         if job is running finish with nothing, WaitForRun= wait until job finished and the run job)
         ``jar``, ``options``, and ``job_name`` are templated so you can use variables in them.
     :param cancel_timeout: How long (in seconds) operator should wait for the pipeline to be
         successfully cancelled when task is being killed.
-    :type cancel_timeout: Optional[int]
     :param wait_until_finished: (Optional)
         If True, wait for the end of pipeline execution before exiting.
         If False, only submits job.
@@ -304,7 +279,6 @@ class DataflowCreateJavaJobOperator(BaseOperator):
 
         If you in your pipeline do not call the wait_for_pipeline method, and pass wait_until_finish=False
         to the operator, the second loop will check once is job not in terminal state and exit the loop.
-    :type wait_until_finished: Optional[bool]
 
     Note that both
     ``dataflow_default_options`` and ``options`` will be merged to specify pipeline
@@ -484,10 +458,8 @@ class DataflowTemplatedJobStartOperator(BaseOperator):
         :ref:`howto/operator:DataflowTemplatedJobStartOperator`
 
     :param template: The reference to the Dataflow template.
-    :type template: str
     :param job_name: The 'jobName' to use when executing the Dataflow template
         (templated).
-    :type job_name: Optional[str]
     :param options: Map of job runtime environment options.
         It will update environment argument if passed.
 
@@ -496,26 +468,18 @@ class DataflowTemplatedJobStartOperator(BaseOperator):
             `https://cloud.google.com/dataflow/pipelines/specifying-exec-params
             <https://cloud.google.com/dataflow/docs/reference/rest/v1b3/RuntimeEnvironment>`__
 
-    :type options: dict
     :param dataflow_default_options: Map of default job environment options.
-    :type dataflow_default_options: dict
     :param parameters: Map of job specific parameters for the template.
-    :type parameters: dict
     :param project_id: Optional, the Google Cloud project ID in which to start a job.
         If set to None or missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param location: Job location.
-    :type location: str
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param poll_sleep: The time in seconds to sleep between polling Google
         Cloud Platform for the dataflow job status while the job is in the
         JOB_STATE_RUNNING state.
-    :type poll_sleep: int
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -524,17 +488,14 @@ class DataflowTemplatedJobStartOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     :param environment: Optional, Map of job runtime environment options.
 
         .. seealso::
             For more information on possible configurations, look at the API documentation
             `https://cloud.google.com/dataflow/pipelines/specifying-exec-params
             <https://cloud.google.com/dataflow/docs/reference/rest/v1b3/RuntimeEnvironment>`__
-    :type environment: Optional[dict]
     :param cancel_timeout: How long (in seconds) operator should wait for the pipeline to be
         successfully cancelled when task is being killed.
-    :type cancel_timeout: Optional[int]
     :param wait_until_finished: (Optional)
         If True, wait for the end of pipeline execution before exiting.
         If False, only submits job.
@@ -568,7 +529,6 @@ class DataflowTemplatedJobStartOperator(BaseOperator):
 
         If you in your pipeline do not call the wait_for_pipeline method, and pass wait_until_finish=False
         to the operator, the second loop will check once is job not in terminal state and exit the loop.
-    :type wait_until_finished: Optional[bool]
 
     It's a good practice to define dataflow_* parameters in the default_args of the dag
     like the project, zone and staging location.
@@ -629,6 +589,7 @@ class DataflowTemplatedJobStartOperator(BaseOperator):
         "environment",
     )
     ui_color = "#0273d4"
+    operator_extra_links = (DataflowJobLink(),)
 
     def __init__(
         self,
@@ -679,6 +640,7 @@ class DataflowTemplatedJobStartOperator(BaseOperator):
 
         def set_current_job(current_job):
             self.job = current_job
+            DataflowJobLink.persist(self, context, self.project_id, self.location, self.job.get("id"))
 
         options = self.dataflow_default_options
         options.update(self.options)
@@ -716,24 +678,18 @@ class DataflowStartFlexTemplateOperator(BaseOperator):
     :param body: The request body. See:
         https://cloud.google.com/dataflow/docs/reference/rest/v1b3/projects.locations.flexTemplates/launch#request-body
     :param location: The location of the Dataflow job (for example europe-west1)
-    :type location: str
     :param project_id: The ID of the GCP project that owns the job.
         If set to ``None`` or missing, the default project_id from the GCP connection is used.
-    :type project_id: Optional[str]
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud
         Platform.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate, if any.
         For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param drain_pipeline: Optional, set to True if want to stop streaming job by draining it
         instead of canceling during killing task instance. See:
         https://cloud.google.com/dataflow/docs/guides/stopping-a-pipeline
-    :type drain_pipeline: bool
     :param cancel_timeout: How long (in seconds) operator should wait for the pipeline to be
         successfully cancelled when task is being killed.
-    :type cancel_timeout: Optional[int]
     :param wait_until_finished: (Optional)
         If True, wait for the end of pipeline execution before exiting.
         If False, only submits job.
@@ -767,10 +723,10 @@ class DataflowStartFlexTemplateOperator(BaseOperator):
 
         If you in your pipeline do not call the wait_for_pipeline method, and pass wait_until_finish=False
         to the operator, the second loop will check once is job not in terminal state and exit the loop.
-    :type wait_until_finished: Optional[bool]
     """
 
     template_fields: Sequence[str] = ("body", "location", "project_id", "gcp_conn_id")
+    operator_extra_links = (DataflowJobLink(),)
 
     def __init__(
         self,
@@ -808,6 +764,7 @@ class DataflowStartFlexTemplateOperator(BaseOperator):
 
         def set_current_job(current_job):
             self.job = current_job
+            DataflowJobLink.persist(self, context, self.project_id, self.location, self.job.get("id"))
 
         job = self.hook.start_flex_template(
             body=self.body,
@@ -841,9 +798,7 @@ class DataflowStartSqlJobOperator(BaseOperator):
         <https://cloud.google.com/sdk/docs/install>`__
 
     :param job_name: The unique name to assign to the Cloud Dataflow job.
-    :type job_name: str
     :param query: The SQL query to execute.
-    :type query: str
     :param options: Job parameters to be executed. It can be a dictionary with the following keys.
 
         For more information, look at:
@@ -851,23 +806,17 @@ class DataflowStartSqlJobOperator(BaseOperator):
         <gcloud beta dataflow sql query>`__
         command reference
 
-    :type options: dict
     :param location: The location of the Dataflow job (for example europe-west1)
-    :type location: str
     :param project_id: The ID of the GCP project that owns the job.
         If set to ``None`` or missing, the default project_id from the GCP connection is used.
-    :type project_id: Optional[str]
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud
         Platform.
-    :type gcp_conn_id: str
     :param delegate_to: The account to impersonate, if any.
         For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param drain_pipeline: Optional, set to True if want to stop streaming job by draining it
         instead of canceling during killing task instance. See:
         https://cloud.google.com/dataflow/docs/guides/stopping-a-pipeline
-    :type drain_pipeline: bool
     """
 
     template_fields: Sequence[str] = (
@@ -878,6 +827,7 @@ class DataflowStartSqlJobOperator(BaseOperator):
         "project_id",
         "gcp_conn_id",
     )
+    template_fields_renderers = {"query": "sql"}
 
     def __init__(
         self,
@@ -956,15 +906,11 @@ class DataflowCreatePythonJobOperator(BaseOperator):
 
     :param py_file: Reference to the python dataflow pipeline file.py, e.g.,
         /some/local/file/path/to/your/python/pipeline/file. (templated)
-    :type py_file: str
     :param job_name: The 'job_name' to use when executing the Dataflow job
         (templated). This ends up being set in the pipeline options, so any entry
         with key ``'jobName'`` or ``'job_name'`` in ``options`` will be overwritten.
-    :type job_name: str
     :param py_options: Additional python options, e.g., ["-m", "-v"].
-    :type py_options: list[str]
     :param dataflow_default_options: Map of default job options.
-    :type dataflow_default_options: dict
     :param options: Map of job specific options.The key must be a dictionary.
         The value can contain different types:
 
@@ -972,50 +918,40 @@ class DataflowCreatePythonJobOperator(BaseOperator):
         * If the value is False, this option will be skipped
         * If the value is True, the single option - ``--key`` (without value) will be added.
         * If the value is list, the many options will be added for each key.
-          If the value is ``['A', 'B']`` and the key is ``key`` then the ``--key=A --key-B`` options
+          If the value is ``['A', 'B']`` and the key is ``key`` then the ``--key=A --key=B`` options
           will be left
         * Other value types will be replaced with the Python textual representation.
 
         When defining labels (``labels`` option), you can also provide a dictionary.
-    :type options: dict
     :param py_interpreter: Python version of the beam pipeline.
         If None, this defaults to the python3.
         To track python versions supported by beam and related
         issues check: https://issues.apache.org/jira/browse/BEAM-1251
-    :type py_interpreter: str
     :param py_requirements: Additional python package(s) to install.
         If a value is passed to this parameter, a new virtual environment has been created with
         additional packages installed.
 
         You could also install the apache_beam package if it is not installed on your system or you want
         to use a different version.
-    :type py_requirements: List[str]
     :param py_system_site_packages: Whether to include system_site_packages in your virtualenv.
         See virtualenv documentation for more information.
 
         This option is only relevant if the ``py_requirements`` parameter is not None.
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
-    :type gcp_conn_id: str
     :param project_id: Optional, the Google Cloud project ID in which to start a job.
         If set to None or missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param location: Job location.
-    :type location: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param poll_sleep: The time in seconds to sleep between polling Google
         Cloud Platform for the dataflow job status while the job is in the
         JOB_STATE_RUNNING state.
-    :type poll_sleep: int
     :param drain_pipeline: Optional, set to True if want to stop streaming job by draining it
         instead of canceling during killing task instance. See:
         https://cloud.google.com/dataflow/docs/guides/stopping-a-pipeline
-    :type drain_pipeline: bool
     :param cancel_timeout: How long (in seconds) operator should wait for the pipeline to be
         successfully cancelled when task is being killed.
-    :type cancel_timeout: Optional[int]
     :param wait_until_finished: (Optional)
         If True, wait for the end of pipeline execution before exiting.
         If False, only submits job.
@@ -1049,7 +985,6 @@ class DataflowCreatePythonJobOperator(BaseOperator):
 
         If you in your pipeline do not call the wait_for_pipeline method, and pass wait_until_finish=False
         to the operator, the second loop will check once is job not in terminal state and exit the loop.
-    :type wait_until_finished: Optional[bool]
     """
 
     template_fields: Sequence[str] = ("options", "dataflow_default_options", "job_name", "py_file")
