@@ -51,29 +51,21 @@ class CloudVisionCreateProductSetOperator(BaseOperator):
 
     :param product_set: (Required) The ProductSet to create. If a dict is provided, it must be of the same
         form as the protobuf message `ProductSet`.
-    :type product_set: dict or google.cloud.vision_v1.types.ProductSet
     :param location: (Required) The region where the ProductSet should be created. Valid regions
         (as of 2019-02-05) are: us-east1, us-west1, europe-west1, asia-east1
-    :type location: str
     :param project_id: (Optional) The project in which the ProductSet should be created. If set to None or
         missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param product_set_id: (Optional) A user-supplied resource id for this ProductSet.
         If set, the server will attempt to use this value as the resource id. If it is
         already in use, an error is returned with code ALREADY_EXISTS. Must be at most
         128 characters long. It cannot contain the character /.
-    :type product_set_id: str
     :param retry: (Optional) A retry object used to retry requests. If `None` is
         specified, requests will not be retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: (Optional) The amount of time, in seconds, to wait for the request to
         complete. Note that if retry is specified, the timeout applies to each individual
         attempt.
-    :type timeout: float
     :param metadata: (Optional) Additional metadata that is provided to the method.
-    :type metadata: sequence[tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -82,7 +74,6 @@ class CloudVisionCreateProductSetOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     # [START vision_productset_create_template_fields]
@@ -153,23 +144,16 @@ class CloudVisionGetProductSetOperator(BaseOperator):
 
     :param location: (Required) The region where the ProductSet is located. Valid regions (as of 2019-02-05)
         are: us-east1, us-west1, europe-west1, asia-east1
-    :type location: str
     :param product_set_id: (Required) The resource id of this ProductSet.
-    :type product_set_id: str
     :param project_id: (Optional) The project in which the ProductSet is located. If set
         to None or missing, the default `project_id` from the Google Cloud connection is used.
-    :type project_id: str
     :param retry: (Optional) A retry object used to retry requests. If `None` is
         specified, requests will not be retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: (Optional) The amount of time, in seconds, to wait for the request to
         complete. Note that if retry is specified, the timeout applies to each individual
         attempt.
-    :type timeout: float
     :param metadata: (Optional) Additional metadata that is provided to the method.
-    :type metadata: sequence[tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -178,7 +162,6 @@ class CloudVisionGetProductSetOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     # [START vision_productset_get_template_fields]
@@ -251,30 +234,21 @@ class CloudVisionUpdateProductSetOperator(BaseOperator):
     :param product_set: (Required) The ProductSet resource which replaces the one on the
         server. If a dict is provided, it must be of the same form as the protobuf
         message `ProductSet`.
-    :type product_set: dict or google.cloud.vision_v1.types.ProductSet
     :param location: (Optional) The region where the ProductSet is located. Valid regions (as of 2019-02-05)
         are: us-east1, us-west1, europe-west1, asia-east1
-    :type location: str
     :param product_set_id: (Optional) The resource id of this ProductSet.
-    :type product_set_id: str
     :param project_id: (Optional) The project in which the ProductSet should be created. If set to None or
         missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param update_mask: (Optional) The `FieldMask` that specifies which fields to update. If update_mask
         isn’t specified, all mutable fields are to be updated. Valid mask path is display_name. If a dict is
         provided, it must be of the same form as the protobuf message `FieldMask`.
-    :type update_mask: dict or google.cloud.vision_v1.types.FieldMask
     :param retry: (Optional) A retry object used to retry requests. If `None` is
         specified, requests will not be retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: (Optional) The amount of time, in seconds, to wait for the request to
         complete. Note that if retry is specified, the timeout applies to each individual
         attempt.
-    :type timeout: float
     :param metadata: (Optional) Additional metadata that is provided to the method.
-    :type metadata: sequence[tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -283,7 +257,6 @@ class CloudVisionUpdateProductSetOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     # [START vision_productset_update_template_fields]
@@ -352,23 +325,16 @@ class CloudVisionDeleteProductSetOperator(BaseOperator):
 
     :param location: (Required) The region where the ProductSet is located. Valid regions (as of 2019-02-05)
         are: us-east1, us-west1, europe-west1, asia-east1
-    :type location: str
     :param product_set_id: (Required) The resource id of this ProductSet.
-    :type product_set_id: str
     :param project_id: (Optional) The project in which the ProductSet should be created.
         If set to None or missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param retry: (Optional) A retry object used to retry requests. If `None` is
         specified, requests will not be retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: (Optional) The amount of time, in seconds, to wait for the request to
         complete. Note that if retry is specified, the timeout applies to each individual
         attempt.
-    :type timeout: float
     :param metadata: (Optional) Additional metadata that is provided to the method.
-    :type metadata: sequence[tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -377,7 +343,6 @@ class CloudVisionDeleteProductSetOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     # [START vision_productset_delete_template_fields]
@@ -444,29 +409,21 @@ class CloudVisionCreateProductOperator(BaseOperator):
 
     :param location: (Required) The region where the Product should be created. Valid regions
         (as of 2019-02-05) are: us-east1, us-west1, europe-west1, asia-east1
-    :type location: str
     :param product: (Required) The product to create. If a dict is provided, it must be of the same form as
         the protobuf message `Product`.
-    :type product: dict or google.cloud.vision_v1.types.Product
     :param project_id: (Optional) The project in which the Product should be created. If set to None or
         missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param product_id: (Optional) A user-supplied resource id for this Product.
         If set, the server will attempt to use this value as the resource id. If it is
         already in use, an error is returned with code ALREADY_EXISTS. Must be at most
         128 characters long. It cannot contain the character /.
-    :type product_id: str
     :param retry: (Optional) A retry object used to retry requests. If `None` is
         specified, requests will not be retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: (Optional) The amount of time, in seconds, to wait for the request to
         complete. Note that if retry is specified, the timeout applies to each individual
         attempt.
-    :type timeout: float
     :param metadata: (Optional) Additional metadata that is provided to the method.
-    :type metadata: sequence[tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -475,7 +432,6 @@ class CloudVisionCreateProductOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     # [START vision_product_create_template_fields]
@@ -549,23 +505,16 @@ class CloudVisionGetProductOperator(BaseOperator):
 
     :param location: (Required) The region where the Product is located. Valid regions (as of 2019-02-05) are:
         us-east1, us-west1, europe-west1, asia-east1
-    :type location: str
     :param product_id: (Required) The resource id of this Product.
-    :type product_id: str
     :param project_id: (Optional) The project in which the Product is located. If set to
         None or missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param retry: (Optional) A retry object used to retry requests. If `None` is
         specified, requests will not be retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: (Optional) The amount of time, in seconds, to wait for the request to
         complete. Note that if retry is specified, the timeout applies to each individual
         attempt.
-    :type timeout: float
     :param metadata: (Optional) Additional metadata that is provided to the method.
-    :type metadata: sequence[tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -574,7 +523,6 @@ class CloudVisionGetProductOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     # [START vision_product_get_template_fields]
@@ -657,31 +605,22 @@ class CloudVisionUpdateProductOperator(BaseOperator):
 
     :param product: (Required) The Product resource which replaces the one on the server. product.name is
         immutable. If a dict is provided, it must be of the same form as the protobuf message `Product`.
-    :type product: dict or google.cloud.vision_v1.types.ProductSet
     :param location: (Optional) The region where the Product is located. Valid regions (as of 2019-02-05) are:
         us-east1, us-west1, europe-west1, asia-east1
-    :type location: str
     :param product_id: (Optional) The resource id of this Product.
-    :type product_id: str
     :param project_id: (Optional) The project in which the Product is located. If set to None or
         missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param update_mask: (Optional) The `FieldMask` that specifies which fields to update. If update_mask
         isn’t specified, all mutable fields are to be updated. Valid mask paths include product_labels,
         display_name, and description. If a dict is provided, it must be of the same form as the protobuf
         message `FieldMask`.
-    :type update_mask: dict or google.cloud.vision_v1.types.FieldMask
     :param retry: (Optional) A retry object used to retry requests. If `None` is
         specified, requests will not be retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: (Optional) The amount of time, in seconds, to wait for the request to
         complete. Note that if retry is specified, the timeout applies to each individual
         attempt.
-    :type timeout: float
     :param metadata: (Optional) Additional metadata that is provided to the method.
-    :type metadata: sequence[tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -690,7 +629,6 @@ class CloudVisionUpdateProductOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     # [START vision_product_update_template_fields]
@@ -764,23 +702,16 @@ class CloudVisionDeleteProductOperator(BaseOperator):
 
     :param location: (Required) The region where the Product is located. Valid regions (as of 2019-02-05) are:
         us-east1, us-west1, europe-west1, asia-east1
-    :type location: str
     :param product_id: (Required) The resource id of this Product.
-    :type product_id: str
     :param project_id: (Optional) The project in which the Product is located. If set to None or
         missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param retry: (Optional) A retry object used to retry requests. If `None` is
         specified, requests will not be retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: (Optional) The amount of time, in seconds, to wait for the request to
         complete. Note that if retry is specified, the timeout applies to each individual
         attempt.
-    :type timeout: float
     :param metadata: (Optional) Additional metadata that is provided to the method.
-    :type metadata: sequence[tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -789,7 +720,6 @@ class CloudVisionDeleteProductOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     # [START vision_product_delete_template_fields]
@@ -851,17 +781,12 @@ class CloudVisionImageAnnotateOperator(BaseOperator):
     :param request: (Required) Annotation request for image or a batch.
         If a dict is provided, it must be of the same form as the protobuf
         message class:`google.cloud.vision_v1.types.AnnotateImageRequest`
-    :type request: list[dict or google.cloud.vision_v1.types.AnnotateImageRequest] for batch or
-        dict or google.cloud.vision_v1.types.AnnotateImageRequest for single image.
     :param retry: (Optional) A retry object used to retry requests. If `None` is
         specified, requests will not be retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: (Optional) The amount of time, in seconds, to wait for the request to
         complete. Note that if retry is specified, the timeout applies to each individual
         attempt.
-    :type timeout: float
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -870,7 +795,6 @@ class CloudVisionImageAnnotateOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     # [START vision_annotate_image_template_fields]
@@ -924,33 +848,24 @@ class CloudVisionCreateReferenceImageOperator(BaseOperator):
 
     :param location: (Required) The region where the Product is located. Valid regions (as of 2019-02-05) are:
         us-east1, us-west1, europe-west1, asia-east1
-    :type location: str
     :param reference_image: (Required) The reference image to create. If an image ID is specified, it is
         ignored.
         If a dict is provided, it must be of the same form as the protobuf message
         :class:`google.cloud.vision_v1.types.ReferenceImage`
-    :type reference_image: dict or google.cloud.vision_v1.types.ReferenceImage
     :param reference_image_id: (Optional) A user-supplied resource id for the ReferenceImage to be added.
         If set, the server will attempt to use this value as the resource id. If it is already in use, an
         error is returned with code ALREADY_EXISTS. Must be at most 128 characters long. It cannot contain
         the character `/`.
-    :type reference_image_id: str
     :param product_id: (Optional) The resource id of this Product.
-    :type product_id: str
     :param project_id: (Optional) The project in which the Product is located. If set to None or
         missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param retry: (Optional) A retry object used to retry requests. If `None` is
         specified, requests will not be retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: (Optional) The amount of time, in seconds, to wait for the request to
         complete. Note that if retry is specified, the timeout applies to each individual
         attempt.
-    :type timeout: float
     :param metadata: (Optional) Additional metadata that is provided to the method.
-    :type metadata: sequence[tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -959,7 +874,6 @@ class CloudVisionCreateReferenceImageOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     # [START vision_reference_image_create_template_fields]
@@ -1035,28 +949,20 @@ class CloudVisionDeleteReferenceImageOperator(BaseOperator):
 
     :param location: (Required) The region where the Product is located. Valid regions (as of 2019-02-05) are:
         us-east1, us-west1, europe-west1, asia-east1
-    :type location: str
     :param reference_image_id: (Optional) A user-supplied resource id for the ReferenceImage to be added.
         If set, the server will attempt to use this value as the resource id. If it is already in use, an
         error is returned with code ALREADY_EXISTS. Must be at most 128 characters long. It cannot contain
         the character `/`.
-    :type reference_image_id: str
     :param product_id: (Optional) The resource id of this Product.
-    :type product_id: str
     :param project_id: (Optional) The project in which the Product is located. If set to None or
         missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param retry: (Optional) A retry object used to retry requests. If `None` is
         specified, requests will not be retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: (Optional) The amount of time, in seconds, to wait for the request to
         complete. Note that if retry is specified, the timeout applies to each individual
         attempt.
-    :type timeout: float
     :param metadata: (Optional) Additional metadata that is provided to the method.
-    :type metadata: sequence[tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -1065,7 +971,6 @@ class CloudVisionDeleteReferenceImageOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     # [START vision_reference_image_create_template_fields]
@@ -1135,26 +1040,18 @@ class CloudVisionAddProductToProductSetOperator(BaseOperator):
         :ref:`howto/operator:CloudVisionAddProductToProductSetOperator`
 
     :param product_set_id: (Required) The resource id for the ProductSet to modify.
-    :type product_set_id: str
     :param product_id: (Required) The resource id of this Product.
-    :type product_id: str
     :param location: (Required) The region where the ProductSet is located. Valid regions (as of 2019-02-05)
         are: us-east1, us-west1, europe-west1, asia-east1
-    :type: str
     :param project_id: (Optional) The project in which the Product is located. If set to None or
         missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param retry: (Optional) A retry object used to retry requests. If `None` is
         specified, requests will not be retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: (Optional) The amount of time, in seconds, to wait for the request to
         complete. Note that if retry is specified, the timeout applies to each individual
         attempt.
-    :type timeout: float
     :param metadata: (Optional) Additional metadata that is provided to the method.
-    :type metadata: sequence[tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -1163,7 +1060,6 @@ class CloudVisionAddProductToProductSetOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     # [START vision_add_product_to_product_set_template_fields]
@@ -1227,26 +1123,18 @@ class CloudVisionRemoveProductFromProductSetOperator(BaseOperator):
         :ref:`howto/operator:CloudVisionRemoveProductFromProductSetOperator`
 
     :param product_set_id: (Required) The resource id for the ProductSet to modify.
-    :type product_set_id: str
     :param product_id: (Required) The resource id of this Product.
-    :type product_id: str
     :param location: (Required) The region where the ProductSet is located. Valid regions (as of 2019-02-05)
         are: us-east1, us-west1, europe-west1, asia-east1
-    :type: str
     :param project_id: (Optional) The project in which the Product is located. If set to None or
         missing, the default project_id from the Google Cloud connection is used.
-    :type project_id: str
     :param retry: (Optional) A retry object used to retry requests. If `None` is
         specified, requests will not be retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: (Optional) The amount of time, in seconds, to wait for the request to
         complete. Note that if retry is specified, the timeout applies to each individual
         attempt.
-    :type timeout: float
     :param metadata: (Optional) Additional metadata that is provided to the method.
-    :type metadata: sequence[tuple[str, str]]
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -1255,7 +1143,6 @@ class CloudVisionRemoveProductFromProductSetOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     # [START vision_remove_product_from_product_set_template_fields]
@@ -1320,25 +1207,17 @@ class CloudVisionDetectTextOperator(BaseOperator):
 
     :param image: (Required) The image to analyze. See more:
         https://googleapis.github.io/google-cloud-python/latest/vision/gapic/v1/types.html#google.cloud.vision_v1.types.Image
-    :type image: dict or google.cloud.vision_v1.types.Image
     :param max_results: (Optional) Number of results to return.
-    :type max_results: int
     :param retry: (Optional) A retry object used to retry requests. If `None` is
         specified, requests will not be retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: Number of seconds before timing out.
-    :type timeout: float
     :param language_hints: List of languages to use for TEXT_DETECTION.
         In most cases, an empty value yields the best results since it enables automatic language detection.
         For languages based on the Latin alphabet, setting language_hints is not needed.
-    :type language_hints: str or list[str]
     :param web_detection_params: Parameters for web detection.
-    :type web_detection_params: dict
     :param additional_properties: Additional properties to be set on the AnnotateImageRequest. See more:
         :class:`google.cloud.vision_v1.types.AnnotateImageRequest`
-    :type additional_properties: dict
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -1347,7 +1226,6 @@ class CloudVisionDetectTextOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     # [START vision_detect_text_set_template_fields]
@@ -1411,25 +1289,17 @@ class CloudVisionTextDetectOperator(BaseOperator):
 
     :param image: (Required) The image to analyze. See more:
         https://googleapis.github.io/google-cloud-python/latest/vision/gapic/v1/types.html#google.cloud.vision_v1.types.Image
-    :type image: dict or google.cloud.vision_v1.types.Image
     :param max_results: Number of results to return.
-    :type max_results: int
     :param retry: (Optional) A retry object used to retry requests. If `None` is
         specified, requests will not be retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: Number of seconds before timing out.
-    :type timeout: float
     :param language_hints: List of languages to use for TEXT_DETECTION.
         In most cases, an empty value yields the best results since it enables automatic language detection.
         For languages based on the Latin alphabet, setting language_hints is not needed.
-    :type language_hints: str or list[str]
     :param web_detection_params: Parameters for web detection.
-    :type web_detection_params: dict
     :param additional_properties: Additional properties to be set on the AnnotateImageRequest. See more:
         https://googleapis.github.io/google-cloud-python/latest/vision/gapic/v1/types.html#google.cloud.vision_v1.types.AnnotateImageRequest
-    :type additional_properties: dict
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -1438,7 +1308,6 @@ class CloudVisionTextDetectOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     # [START vision_document_detect_text_set_template_fields]
@@ -1501,19 +1370,13 @@ class CloudVisionDetectImageLabelsOperator(BaseOperator):
 
     :param image: (Required) The image to analyze. See more:
         https://googleapis.github.io/google-cloud-python/latest/vision/gapic/v1/types.html#google.cloud.vision_v1.types.Image
-    :type image: dict or google.cloud.vision_v1.types.Image
     :param max_results: Number of results to return.
-    :type max_results: int
     :param retry: (Optional) A retry object used to retry requests. If `None` is
         specified, requests will not be retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: Number of seconds before timing out.
-    :type timeout: float
     :param additional_properties: Additional properties to be set on the AnnotateImageRequest. See more:
         https://googleapis.github.io/google-cloud-python/latest/vision/gapic/v1/types.html#google.cloud.vision_v1.types.AnnotateImageRequest
-    :type additional_properties: dict
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -1522,7 +1385,6 @@ class CloudVisionDetectImageLabelsOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     # [START vision_detect_labels_template_fields]
@@ -1579,19 +1441,13 @@ class CloudVisionDetectImageSafeSearchOperator(BaseOperator):
 
     :param image: (Required) The image to analyze. See more:
         https://googleapis.github.io/google-cloud-python/latest/vision/gapic/v1/types.html#google.cloud.vision_v1.types.Image
-    :type image: dict or google.cloud.vision_v1.types.Image
     :param max_results: Number of results to return.
-    :type max_results: int
     :param retry: (Optional) A retry object used to retry requests. If `None` is
         specified, requests will not be retried.
-    :type retry: google.api_core.retry.Retry
     :param timeout: Number of seconds before timing out.
-    :type timeout: float
     :param additional_properties: Additional properties to be set on the AnnotateImageRequest. See more:
         https://googleapis.github.io/google-cloud-python/latest/vision/gapic/v1/types.html#google.cloud.vision_v1.types.AnnotateImageRequest
-    :type additional_properties: dict
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :type gcp_conn_id: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -1600,7 +1456,6 @@ class CloudVisionDetectImageSafeSearchOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     # [START vision_detect_safe_search_template_fields]
