@@ -36,17 +36,13 @@ class GCSObjectExistenceSensor(BaseSensorOperator):
     Checks for the existence of a file in Google Cloud Storage.
 
     :param bucket: The Google Cloud Storage bucket where the object is.
-    :type bucket: str
     :param object: The name of the object to check in the Google cloud
         storage bucket.
-    :type object: str
     :param google_cloud_conn_id: The connection ID to use when
         connecting to Google Cloud Storage.
-    :type google_cloud_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -55,7 +51,6 @@ class GCSObjectExistenceSensor(BaseSensorOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -111,21 +106,16 @@ class GCSObjectUpdateSensor(BaseSensorOperator):
     Checks if an object is updated in Google Cloud Storage.
 
     :param bucket: The Google Cloud Storage bucket where the object is.
-    :type bucket: str
     :param object: The name of the object to download in the Google cloud
         storage bucket.
-    :type object: str
     :param ts_func: Callback for defining the update condition. The default callback
         returns execution_date + schedule_interval. The callback takes the context
         as parameter.
-    :type ts_func: function
     :param google_cloud_conn_id: The connection ID to use when
         connecting to Google Cloud Storage.
-    :type google_cloud_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -134,7 +124,6 @@ class GCSObjectUpdateSensor(BaseSensorOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -182,17 +171,13 @@ class GCSObjectsWithPrefixExistenceSensor(BaseSensorOperator):
     through XCom for downstream tasks.
 
     :param bucket: The Google Cloud Storage bucket where the object is.
-    :type bucket: str
     :param prefix: The name of the prefix to check in the Google cloud
         storage bucket.
-    :type prefix: str
     :param google_cloud_conn_id: The connection ID to use when
         connecting to Google Cloud Storage.
-    :type google_cloud_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -201,7 +186,6 @@ class GCSObjectsWithPrefixExistenceSensor(BaseSensorOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -279,30 +263,23 @@ class GCSUploadSessionCompleteSensor(BaseSensorOperator):
 
     :param bucket: The Google Cloud Storage bucket where the objects are.
         expected.
-    :type bucket: str
     :param prefix: The name of the prefix to check in the Google cloud
         storage bucket.
     :param inactivity_period: The total seconds of inactivity to designate
         an upload session is over. Note, this mechanism is not real time and
         this operator may not return until a poke_interval after this period
         has passed with no additional objects sensed.
-    :type inactivity_period: float
     :param min_objects: The minimum number of objects needed for upload session
         to be considered valid.
-    :type min_objects: int
     :param previous_objects: The set of object ids found during the last poke.
-    :type previous_objects: set[str]
     :param allow_delete: Should this sensor consider objects being deleted
         between pokes valid behavior. If true a warning message will be logged
         when this happens. If false an error will be raised.
-    :type allow_delete: bool
     :param google_cloud_conn_id: The connection ID to use when connecting
         to Google Cloud Storage.
-    :type google_cloud_conn_id: str
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
         domain-wide delegation enabled.
-    :type delegate_to: str
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -311,7 +288,6 @@ class GCSUploadSessionCompleteSensor(BaseSensorOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :type impersonation_chain: Union[str, Sequence[str]]
     """
 
     template_fields: Sequence[str] = (
@@ -367,7 +343,6 @@ class GCSUploadSessionCompleteSensor(BaseSensorOperator):
         has passed and updates the state of the sensor accordingly.
 
         :param current_objects: set of object ids in bucket during last poke.
-        :type current_objects: set[str]
         """
         current_num_objects = len(current_objects)
         if current_objects > self.previous_objects:
